package POWER::Event::IO::const;

use version; $VERSION = qv('0.1.0');    # update POD & Changes & README

use warnings;
use strict;
use Carp;

use Errno qw( EAGAIN EINTR EINPROGRESS );
use Socket;

use POWER::Epoll 2.0.0;


BEGIN {
    # Cache for speed:
    our ($EAGAIN, $EINTR, $EINPROGRESS);
    *EAGAIN         = \EAGAIN;
    *EINTR          = \EINTR;
    *EINPROGRESS    = \EINPROGRESS;
    our ($AF_INET, $PROTO_TCP, $PROTO_UDP, $SOCK_STREAM, $SOCK_DGRAM);
    *PROTO_TCP      = \getprotobyname('tcp');
    *PROTO_UDP      = \getprotobyname('udp');
    *AF_INET        = \AF_INET;
    *SOCK_STREAM    = \SOCK_STREAM;
    *SOCK_DGRAM     = \SOCK_DGRAM;
    our ($SOL_SOCKET, $SO_REUSEADDR, $REUSEADDR_VAL, $SOMAXCONN);
    *SOL_SOCKET     = \SOL_SOCKET;
    *SO_REUSEADDR   = \SO_REUSEADDR;
    *REUSEADDR_VAL  = \pack('L!', 1);
    *SOMAXCONN      = \SOMAXCONN;
    our ($FIONBIO, $IOCTL_TRUE);
    *FIONBIO        = \0x5421;
    $IOCTL_TRUE     = "\1\0\0\0";   # ioctl()     


    # :
    our ($ERR, $RESOLVED, $CONNECTED, $ACCEPTED, $IN, $OUT, $EOF, $SENT);
    *ERR            = \(1<<0);
    *RESOLVED       = \(1<<1);
    *CONNECTED      = \(1<<2);
    *ACCEPTED       = \(1<<3);
    *IN             = \(1<<4);
    *OUT            = \(1<<5);
    *EOF            = \(1<<6);
    *SENT           = \(1<<7);

    # :
    our ($RESOLVING, $CONNECTING, $HANDLING);
    *RESOLVING      = \(1<<0);
    *CONNECTING     = \(1<<1);
    *HANDLING       = \(1<<2);

    # :
    our ($STREAM_IO, $PACKET_IO);
    *STREAM_IO      = \(1<<0);
    *PACKET_IO      = \(1<<1);
}


sub import {
    my $pkg = caller(0);
    no strict 'refs';
    *{$pkg.'::'.$_} = \${$_} for qw(
        EAGAIN EINTR EINPROGRESS
        PROTO_TCP PROTO_UDP AF_INET SOCK_STREAM SOCK_DGRAM
        SOL_SOCKET SO_REUSEADDR REUSEADDR_VAL SOMAXCONN
        FIONBIO IOCTL_TRUE

        ERR RESOLVED CONNECTED ACCEPTED IN OUT EOF SENT
        RESOLVING CONNECTING HANDLING
        PACKET_IO STREAM_IO
        );
}


1; # Magic true value required at end of module
__END__

=head1 DESCRIPTION

See L<POWER::Event::IO>.
