use warnings;
use strict;
use Test::More tests => 4;
use Test::Exception;
use Test::MockModule;

use Socket;

use POWER::Event;
use POWER::Event::IO;
use POWER::Utils::IO;


socketpair my $client, my $server, AF_UNIX, SOCK_STREAM, PF_UNSPEC or die "socketpair: $!";
POWER::Event::IO->new({
    fh          => $server,
    cb          => \&server,
    wait_for    => $IN,
});
POWER::Event::IO->new({
    fh          => $client,
    cb          => \&client,
    wait_for    => $EOF,
    out_buf     => 'test',
    in_buf_limit=> 1024,
});

my @Wait = (
    ['server',      $IN         ],
    ['client',      $EOF        ],
);

eval { loop() };
die "out of loop: $@";


sub server {
    my ($io) = @_;
    is_deeply(shift @Wait, ['server', $io->{events}], 'server');
    die "server unexpected event: $io->{err}" if $io->{events} != $IN;
    is($io->{in_buf}, 'test', '  got "test" request');
    $io->write('test passed');
    shutdown $io->{fh}, 1;
}

sub client {
    my ($io) = @_;
    is_deeply(shift @Wait, ['client', $io->{events}], 'client');
    die "server unexpected event: $io->{err}" if $io->{events} != $EOF;
    is($io->{in_buf}, 'test passed', '  got "test passed" reply');
    exit;
}

